@@ -12,9 +12,7 @@ sub _croak {
 
 use XSLoader;
 BEGIN {
-    our $VERSION = '1.0703';
-    our $XS_VERSION = $VERSION;
-    $VERSION = eval $VERSION;
+    our $VERSION = '1.0704';
     XSLoader::load;
 }
 
@@ -283,7 +281,15 @@ sub info {
         keyword  => $info->{declarator},
         invocant => _mkparam1($info->{invocant}),
         slurpy   => _mkparam1($info->{slurpy}),
-        (map +("_$_" => _mkparams @{$info->{$_}}), glob '{positional,named}_{required,optional}')
+        (
+            map +("_$_" => _mkparams @{$info->{$_}}),
+            qw(
+                positional_required
+                positional_optional
+                named_required
+                named_optional
+            )
+        )
     )
 }
 
